import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';
import 'package:namer_app/list.dart';
import 'package:namer_app/login.dart';
import 'package:namer_app/lang.dart';

void main() {
  runApp(MyApp());
}

final _router = GoRouter(
  routes: [
    GoRoute(path: '/', builder: (context, state) => MyHomePage(), //),
        routes: [
          GoRoute(
            path: 'login',
            builder: (context, state) => LoginPage(),
          ),
          GoRoute(
            path: 'list',
            builder: (context, state) => ListPage(),
          ),
        ]),
  ],
);

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp.router(
      title: 'TelNow Lat',
      theme: ThemeData(
        useMaterial3: true,
        colorScheme:
            ColorScheme.fromSeed(seedColor: Color.fromARGB(255, 0, 255, 255)),
      ),
      routerConfig: _router,
    );
  }
}

class MyHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      //backgroundColor: Theme.of(context).colorScheme.primaryContainer,
      body: Container(
        decoration: BoxDecoration(
            image: DecorationImage(
          image: AssetImage("assets/images/building.jpg"),
          fit: BoxFit.cover,
        )),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Lang(),
            Expanded(
              child: Center(
                  child: Text(
                'telnow',
                style: TextStyle(color: Colors.orange, fontSize: 48),
              )),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 120, right: 120),
              child: Text(
                'Silakan pindai QR terlebih dulu untuk mulai menggunakan aplikasi.',
                softWrap: true,
                textAlign: TextAlign.center,
                style: TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.bold,
                    color: Colors.white),
              ),
            ),
            Expanded(
              child: Center(child: Pindai()),
            ),
            Column(
              children: [
                Text('Kebijakan Privasi',
                    style: TextStyle(
                        fontSize: 16,
                        decoration: TextDecoration.underline,
                        fontWeight: FontWeight.w800,
                        color: Colors.white)),
                Text('Versi 4.0.0.0',
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w800,
                      color: Colors.white,
                    ))
              ],
            ),
            Container(
              color: Theme.of(context).colorScheme.primaryContainer,
            )
          ],
        ),
      ),
    );
  }
}

class Pindai extends StatelessWidget {
  const Pindai({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () => context.go('/login'),
      style: ButtonStyle(
          padding: MaterialStateProperty.all<EdgeInsets>(EdgeInsets.all(50)),
          foregroundColor: MaterialStateProperty.all<Color>(Colors.black),
          backgroundColor:
              MaterialStateProperty.all(Color.fromARGB(1, 7, 140, 132)),
          shape: MaterialStateProperty.all<RoundedRectangleBorder>(
              RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(18.0),
          ))),
      child: Text(
        'Pindai QR',
        style: TextStyle(color: Colors.white),
      ),
    );
  }
}
